@@ -10,13 +10,17 @@ import publication
 
 import aws_cdk.aws_certificatemanager._jsii
 import aws_cdk.aws_cloudfront._jsii
+import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_route53._jsii
 import aws_cdk.aws_route53_patterns._jsii
 import aws_cdk.aws_route53_targets._jsii
 import aws_cdk.aws_s3._jsii
 import aws_cdk.aws_s3_deployment._jsii
 import aws_cdk.core._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("cdk-spa-deploy", "1.47.0", __name__[0:-6], "cdk-spa-deploy@1.47.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "cdk-spa-deploy", "1.50.0", __name__[0:-6], "cdk-spa-deploy@1.50.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
